#include <iostream>
#include <string>

#include "vtkSmartPointer.h"
#include "vtkTecplotReader.h"
#include "vtkUnstructuredGrid.h"
#include "vtkArrayCalculator.h"
#include "vtkGradientFilter.h"
#include "vtkArrowSource.h"
#include "vtkTransform.h"
#include "vtkTransformPolyDataFilter.h"
#include "vtkGlyph3D.h"
#include "vtkPolyDataMapper.h"
#include "vtkActor.h"
#include "vtkRenderer.h"
#include "vtkRenderWindow.h"
#include "vtkRenderWindowInteractor.h"
#include "vtkInteractorStyleTrackballCamera.h"

using namespace std;

int main(int argc, char** argv)
{

  cout << "Loading tecplot file" << endl;
	vtkSmartPointer<vtkTecplotReader> reader = vtkTecplotReader::New();
	reader->SetFileName("sphere.tec");
	reader->Update();
  cout << "... done!" << endl;

  cout << endl << "Data arrays: " << endl;
  for (int i = 0; i < reader->GetNumberOfDataArrays(); ++i) {
    cout << "\t" << reader->GetDataArrayName(i) << endl;
  }
  cout << endl;

  cout << "Calculating vector field from scalars" << endl;
	vtkSmartPointer<vtkArrayCalculator> mag = vtkArrayCalculator::New();
	mag->SetAttributeModeToUsePointData();
	mag->AddScalarArrayName("Mx");
	mag->AddScalarArrayName("My");
	mag->AddScalarArrayName("Mz");
	mag->SetFunction("Mx*iHat + My*jHat + Mz*kHat");
	mag->SetResultArrayName("mag");
	mag->Update();
  cout << "... done!" << endl;

}

